@@ -29,6 +29,7 @@ APP_NAME_TO_USECASE = {
     "concrete_crack_detection": "concrete_crack_detection",
     "lane_detection" : "lane_detection",
     "shelf_inventory" :"shelf_inventory",
+    "smoker_detection": "smoker_detection"
 }
 
 APP_NAME_TO_CATEGORY = {
@@ -62,6 +63,7 @@ APP_NAME_TO_CATEGORY = {
     "concrete_crack_detection": "general",
     "lane_detection" : "traffic",
     "shelf_inventory" : "retail",
+    "smoker_detection": "general"
 }
 
 def get_usecase_from_app_name(app_name: str) -> str:
