@@ -448,6 +448,7 @@ class ConfigManager:
             'windmill_maintenance': None,
             'face_emotion': None,
             'flower_segmentation': None,
+            'smoker_detection': None,
 
             #Put all image based usecases here::
             'blood_cancer_detection_img': None,
@@ -794,6 +795,14 @@ class ConfigManager:
         except ImportError:
             return None
     
+    def smoker_detection_config_class(self):
+        """Register a configuration class for a use case."""
+        try:
+            from ..usecases.smoker_detection import SmokerDetectionConfig
+            return SmokerDetectionConfig
+        except ImportError:
+            return None
+    
     #put all image based usecases here::
     def blood_cancer_detection_config_class(self):
         """Register a configuration class for a use case."""
@@ -1618,6 +1627,22 @@ class ConfigManager:
                 alert_config=alert_config,
                 **kwargs
             )
+        
+        elif usecase == "smoker_detection":
+            # Import here to avoid circular import
+            from ..usecases.smoker_detection import SmokerDetectionConfig
+
+            # Handle nested configurations
+            alert_config = kwargs.pop("alert_config", None)
+            if alert_config and isinstance(alert_config, dict):
+                alert_config = AlertConfig(**alert_config)
+
+            config = SmokerDetectionConfig(
+                category=category or "general",
+                usecase=usecase,
+                alert_config=alert_config,
+                **kwargs
+            )
 
         
         #Add IMAGE based usecases here::
@@ -2003,6 +2028,11 @@ class ConfigManager:
             from ..usecases.flower_segmentation import FlowerConfig
             default_config = FlowerConfig()
             return default_config.to_dict()
+        elif usecase == "smoker_detection":
+            # Import here to avoid circular import
+            from ..usecases.smoker_detection import SmokerDetectionConfig
+            default_config = SmokerDetectionConfig()
+            return default_config.to_dict()
 
         #Add all image based usecases here
         elif usecase == "blood_cancer_detection_img":
