@@ -83,6 +83,7 @@ from .usecases import (
     CarPartSegmentationUseCase,
     WindmillMaintenanceUseCase,
     FlowerUseCase,
+    SmokerDetectionUseCase,
 
     #Put all IMAGE based usecases here
     BloodCancerDetectionUseCase,
@@ -204,6 +205,7 @@ class PostProcessor:
         registry.register_use_case("agriculture", "flower_segmentation", FlowerUseCase)
         registry.register_use_case("general", "parking_det", ParkingUseCase)
         registry.register_use_case("agriculture", "leaf_det", LeafUseCase)
+        registry.register_use_case("general", "smoker_detection", SmokerDetectionUseCase)
 
         #Put all IMAGE based usecases here
         registry.register_use_case("healthcare", "bloodcancer_img_detection", BloodCancerDetectionUseCase)
@@ -354,8 +356,8 @@ class PostProcessor:
                 result = use_case.process(data, parsed_config, context, stream_info)
             elif isinstance(use_case, LeafUseCase):
                 result = use_case.process(data, parsed_config, context, stream_info)
-
-            
+            elif isinstance(use_case, SmokerDetectionUseCase):
+                result = use_case.process(data, parsed_config, context, stream_info)
 
             
             #Put all IMAGE based usecases here
